.. nes-torch documentation master file, created by
   sphinx-quickstart on Fri Apr 16 19:59:04 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to nes-torch's documentation!
=====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   reference
   config


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
